@@ -1,3 +1,5 @@
+from http import HTTPStatus
+
 from django.test import TestCase
 
 from allauth.socialaccount.providers.baidu.provider import BaiduProvider
@@ -10,7 +12,7 @@ class BaiduTests(OAuth2TestsMixin, TestCase):
 
     def get_mocked_response(self):
         return MockedResponse(
-            200,
+            HTTPStatus.OK,
             """
 {"portrait": "78c0e9839de59bbde7859ccf43",
 "uname": "\u90dd\u56fd\u715c", "uid": "3225892368"}""",
