@@ -1,3 +1,5 @@
+from http import HTTPStatus
+
 from django.test import TestCase
 
 from allauth.socialaccount.providers.zoom.provider import ZoomProvider
@@ -10,7 +12,7 @@ class ZoomTests(OAuth2TestsMixin, TestCase):
 
     def get_mocked_response(self):
         return MockedResponse(
-            200,
+            HTTPStatus.OK,
             """
 {
   "id": "KdYKjnimT4KPd8FFgQt9FQ",
